@@ -76,12 +76,20 @@ class IterableIPShell:
         IPython.terminal.interactiveshell.raw_input_original = input_func
       else:
         IPython.frontend.terminal.interactiveshell.raw_input_original = input_func
-    if cin:
-      io.stdin = io.IOStream(cin)
-    if cout:
-      io.stdout = io.IOStream(cout)
-    if cerr:
-      io.stderr = io.IOStream(cerr)
+    if IPython.version_info < (8,):
+      if cin:
+        io.stdin = io.IOStream(cin)
+      if cout:
+        io.stdout = io.IOStream(cout)
+      if cerr:
+        io.stderr = io.IOStream(cerr)
+    else:
+      if cin:
+        sys.stdin = cin
+      if cout:
+        sys.stdout = cout
+      if cerr:
+        sys.stderr = cerr
 
     # This is to get rid of the blockage that accurs during 
     # IPython.Shell.InteractiveShell.user_setup()
@@ -99,11 +107,11 @@ class IterableIPShell:
     cfg.InteractiveShell.colors = "Linux"
     cfg.Completer.use_jedi = False
 
-    # InteractiveShell's __init__ overwrites io.stdout,io.stderr with
-    # sys.stdout, sys.stderr, this makes sure they are right
-    #
-    old_stdout, old_stderr = sys.stdout, sys.stderr
-    sys.stdout, sys.stderr = io.stdout.stream, io.stderr.stream
+    if IPython.version_info < (8,):
+      # InteractiveShell's __init__ overwrites io.stdout,io.stderr with
+      # sys.stdout, sys.stderr, this makes sure they are right
+      old_stdout, old_stderr = sys.stdout, sys.stderr
+      sys.stdout, sys.stderr = io.stdout.stream, io.stderr.stream
 
     # InteractiveShell inherits from SingletonConfigurable, so use instance()
     #
@@ -114,7 +122,8 @@ class IterableIPShell:
       self.IP = IPython.frontend.terminal.embed.InteractiveShellEmbed.instance(\
               config=cfg, user_ns=user_ns)
 
-    sys.stdout, sys.stderr = old_stdout, old_stderr
+    if IPython.version_info < (8,):
+      sys.stdout, sys.stderr = old_stdout, old_stderr
 
     self.IP.system = lambda cmd: self.shell(self.IP.var_expand(cmd),
                                             header='IPython system call: ')
@@ -140,6 +149,7 @@ class IterableIPShell:
     # But it definitely does not work any more with >= 7.0.0
     self.no_input_splitter = parse_version(IPython.release.version) >= parse_version('5.8.0')
     self.lines = []
+    self.indent_spaces = ''
 
   def __update_namespace(self):
     '''
@@ -155,14 +165,16 @@ class IterableIPShell:
     '''
     self.history_level = 0
 
-    # this is needed because some functions in IPython use 'print' to print
-    # output (like 'who')
-    #
-    orig_stdout = sys.stdout
-    sys.stdout = IPython.utils.io.stdout
+    if IPython.version_info < (8,):
+      # this is needed because some functions in IPython use 'print' to print
+      # output (like 'who')
+
+      orig_stdout = sys.stdout
+      sys.stdout = IPython.utils.io.stdout
+
+      orig_stdin = sys.stdin
+      sys.stdin = IPython.utils.io.stdin;
 
-    orig_stdin = sys.stdin
-    sys.stdin = IPython.utils.io.stdin;
     self.prompt = self.generatePrompt(self.iter_more)
 
     self.IP.hooks.pre_prompt_hook()
@@ -178,20 +190,21 @@ class IterableIPShell:
       line = self.IP.raw_input(self.prompt)
     except KeyboardInterrupt:
       self.IP.write('\nKeyboardInterrupt\n')
-      self.IP.input_splitter.reset()
+      if self.no_input_splitter:
+        self.lines = []
+      else:
+        self.IP.input_splitter.reset()
     except:
       self.IP.showtraceback()
     else:
       if self.no_input_splitter:
         self.lines.append(line)
-        self.iter_more = self.IP.check_complete('\n'.join(self.lines))[0] == 'incomplete'
+        (status, self.indent_spaces) = self.IP.check_complete('\n'.join(self.lines))
+        self.iter_more = status == 'incomplete'
       else:
         self.IP.input_splitter.push(line)
         self.iter_more = self.IP.input_splitter.push_accepts_more()
       self.prompt = self.generatePrompt(self.iter_more)
-      if (self.IP.SyntaxTB.last_syntax_error and
-          self.IP.autoedit_syntax):
-          self.IP.edit_syntax_error()
       if not self.iter_more:
           if self.no_input_splitter:
             source_raw = '\n'.join(self.lines)
@@ -208,8 +221,9 @@ class IterableIPShell:
           self.IP.rl_do_indent = True
           pass
 
-    sys.stdout = orig_stdout
-    sys.stdin = orig_stdin
+    if IPython.version_info < (8,):
+      sys.stdout = orig_stdout
+      sys.stdin = orig_stdin
 
   def generatePrompt(self, is_continuation):
     '''
@@ -320,7 +334,7 @@ class IterableIPShell:
             return str1[:i]
         return str1
       if possibilities[1]:
-        common_prefix = reduce(_commonPrefix, possibilities[1]) or line[-1]
+        common_prefix = reduce(_commonPrefix, possibilities[1]) or split_line[-1]
         completed = line[:-len(split_line[-1])]+common_prefix
       else:
         completed = line
@@ -374,7 +388,9 @@ class ConsoleView(gtk.TextView):
                   '1;30': 'DarkGray',  '1;31': 'DarkRed',
                   '1;32': 'SeaGreen',  '1;33': 'Yellow',
                   '1;34': 'LightBlue', '1;35': 'MediumPurple',
-                  '1;36': 'LightCyan', '1;37': 'White'}
+                  '1;36': 'LightCyan', '1;37': 'White',
+                  '38;5;241': 'Gray',
+                  '39': 'Black' }
 
   def __init__(self):
     '''
@@ -511,7 +527,10 @@ class ConsoleView(gtk.TextView):
     self.text_buffer.place_cursor(self.text_buffer.get_end_iter())
 
     if self.IP.rl_do_indent:
-      indentation = self.IP.input_splitter.indent_spaces * ' '
+      if self.no_input_splitter:
+        indentation = self.indent_spaces
+      else:
+        indentation = self.IP.input_splitter.indent_spaces * ' '
       self.text_buffer.insert_at_cursor(indentation)
 
   def onKeyPress(self, widget, event):
@@ -547,6 +566,15 @@ class ConsoleView(gtk.TextView):
       insert_iter.backward_cursor_position()
       if not insert_iter.editable(True):
         return True
+    elif event.state & gdk.ModifierType.CONTROL_MASK and event.keyval in [ord('L'), ord('l')]:
+        # clear previous output on Ctrl+L, but remember current input line + cursor position
+        cursor_offset = self.text_buffer.get_property('cursor-position')
+        cursor_pos_in_line = cursor_offset - start_iter.get_offset() + len(self.prompt)
+        current_input = self.text_buffer.get_text(start_iter, self.text_buffer.get_end_iter(), False)
+        self.text_buffer.set_text(self.prompt + current_input)
+        self.text_buffer.move_mark(self.line_start, self.text_buffer.get_iter_at_offset(len(self.prompt)))
+        self.text_buffer.place_cursor(self.text_buffer.get_iter_at_offset(cursor_pos_in_line))
+        return True
     elif not event.string:
       pass
     elif start_iter.compare(insert_iter) <= 0 and \
